@@ -222,7 +222,7 @@ class Record:
         self.__queried = False
     
     def __repr__(self):
-        return f"{self.database} - {len(self.data)} results\n{colors['INFO']}Fields{colors['normal']} - {[x['name'] for x in self.schema['columns']]}"
+        return f"{self.database} - {len(self.data) if len(self.results) == 0 else len(self.results)} results\n{colors['INFO']}Fields{colors['normal']} - {[x['name'] for x in self.schema['columns']]}"
 
     #PUBLIC METHODS
     
