@@ -1,4 +1,4 @@
-from pybasedb import pyBase, create_database_from_schema
+from pybasedb.pyBase import pyBase, create_database_from_schema
 from os import listdir, mkdir
 import os.path as path
 import json
